@@ -18,11 +18,11 @@ CPAN::Mini::Inject - Inject modules into a CPAN::Mini mirror.
 
 =head1 Version
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 our @ISA=qw( CPAN::Mini );
 
 =head1 Synopsis
@@ -114,6 +114,8 @@ parsecfg expects the config file in the following format:
  local: /www/CPAN
  remote: ftp://ftp.cpan.org/pub/CPAN ftp://ftp.kernel.org/pub/CPAN
  repository: /work/mymodules
+ passive: yes
+ dirmode: 0755
 
 Description of options:
 
@@ -136,6 +138,11 @@ Location to store modules to add to the local CPAN::Mini mirror.
 
 Enable passive FTP.
 
+=item * dirmode
+
+Set the permissions of created directories to the specified mode. The default
+value is based on umask if supported.
+
 =back
 
 If either local or remote are not defined parsecfg croaks.
@@ -223,6 +230,8 @@ sub update_mirror {
   $self->testremote($options{trace}) unless($self->{site});
   $options{remote}||=$self->{site};
 
+  $options{dirmode}||=oct($self->_cfg('dirmode')||sprintf('0%o',0777 &~ umask()));
+
   ref($self)->SUPER::update_mirror( %options );
 }
 
